#!/usr/bin/env python
# coding: utf-8

import numpy as np
import math
from qiskit import(
QuantumCircuit,
QuantumRegister,
ClassicalRegister,
execute,
Aer)
from qiskit.visualization import plot_histogram
from qiskit.quantum_info.operators import Operator 

A_G = [ 
    [math.sqrt(3)/2, 1/2*complex(0,1)], 
    [1/2, -math.sqrt(3)/2*complex(0,1)]
]

gate_G = Operator(A_G) 

print('Operatator is unitary:', gate_G.is_unitary()) 

# Set up circuit
circuit = QuantumCircuit(2, 2) 
circuit.append(gate_G, [0],) 
circuit.x(1)
circuit.cx(0,1)
circuit.measure([0,1], [0,1])

circuit.draw(output='mpl')

# Select Simulator
backend = Aer.get_backend('qasm_simulator')  

# Define the run parameters and execute
job = execute( circuit, backend, shots=1024 )

# Tally the results
collapsed_states_array = job.result().get_counts()
print(collapsed_states_array) 



